use ansi_term::ANSIGenericString;
use ansi_term::Colour::RGB;
use std::process::Command;

// SSH indicator symbol
pub const GIT_SYMBOL: &str = "\u{276F}"; // "❯"
pub const MAIN_COL: ansi_term::Colour = RGB(178, 98, 44); //
pub const DEV_COL: ansi_term::Colour = RGB(54, 159, 150); //
pub const OTHER_COL: ansi_term::Colour = RGB(82, 82, 82); //
pub const NORMIE_COL: ansi_term::Colour = RGB(255, 255, 255); // White

pub fn info() -> Option<(String, String)> {
    let output = Command::new("git")
        .arg("rev-parse")
        .arg("--show-toplevel") // Repo root
        .arg("--abbrev-ref") // Git branch
        .arg("HEAD")
        .output();
    match output {
        Ok(output) if output.status.success() => {
            let stdout = String::from_utf8_lossy(&output.stdout); // Get cmd output
            let output_string = stdout.trim();
            let parts: Vec<&str> = output_string.split('\n').collect();

            if parts.len() == 2 {
                Some((parts[0].to_string(), parts[1].to_string()))
            } else {
                None
            }
        }
        _ => None,
    }
}

//Git branch indicator
pub fn indicator(branch: Option<String>) -> ANSIGenericString<'static, str> {
    match branch {
        Some(b) => match b.as_str() {
            "main" => MAIN_COL.paint(GIT_SYMBOL),
            "dev" => DEV_COL.paint(GIT_SYMBOL),
            _ => OTHER_COL.paint(GIT_SYMBOL),
        },
        None => NORMIE_COL.paint(GIT_SYMBOL),
    }
}
